@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/openshift/origin/pkg/oc/cli"
-	"github.com/openshift/origin/tools/clicheck/sanity"
+	"github.com/openshift/oc/pkg/cli"
+	"github.com/openshift/oc/tools/clicheck/sanity"
 )
 
 func main() {
